@@ -1,6 +1,7 @@
 import tkinter as tk
 from tkinter import messagebox
 from tkinter import filedialog
+from tkinter import ttk
 import freesasa
 from Bio.PDB import PDBParser
 from Bio.PDB import Selection
@@ -22,6 +23,8 @@ class GUI:
         self.frame = tk.Frame()
         self.frame.grid()
         self.title = master.title("AMIVA-F analysis of mutations in variants of human Filamin C")
+
+
         #master.state = "500x1000"
 
         #master.state = "zoomed"
@@ -100,7 +103,7 @@ class Entry_formular:
         self.header.grid(row=0, column=0, sticky="nswe", ipady=5)
         self.label1 = tk.Label(self.frame, text="Please enter your mutation of interest into the entry field below.")
         self.label1.grid(row=1, column=0, columnspan=1, sticky="news")
-        self.label2 = tk.Label(self.frame, text="Accepted format: e.g M82K", font="Helvetica 12 bold")
+        self.label2 = tk.Label(self.frame, text="Accepted format: e.g M82K", font="Helvetica 10 bold")
         self.label2.grid(row=2, column=0, ipadx=10, sticky="news")
         self.label3 = tk.Label(self.frame, text="for Methionine (M) being mutated to Lysine (K) ")
         self.label3.grid(row=3, column=0, ipadx=10, sticky="news")
@@ -111,15 +114,21 @@ class Entry_formular:
         self.entry1 = tk.Entry(self.frame)
         self.entry1.grid(row=5, column=0)
         self.lblexplain = tk.Label(self.frame, text="After entering your desired mutation"
-                                                    ", the green button will calculate and fill in all parameters")
+                                                    ", the blue button will give you a prediction after a couple of seconds")
         self.lblexplain.grid(row=6, column=0)
-        self.button = tk.Button(self.frame, text="Calculate everything for me!"
-                                , relief="ridge", borderwidth=4, bg="green", fg="white",
-                                command=self.hydrophobicity_atomnumb)
-        self.button.grid(row=7, column=0, pady=10)
+        self.button = tk.Button(self.frame, text="Predict mutation!"
+                                , relief="ridge", borderwidth=4, bg="blue", fg="white",height=2, width=15,
+                                command=lambda:[self.hydrophobicity_atomnumb(), entry_form.outfile_handler_weka()])
+        self.button.config(font="helvetica 10 bold")
+        self.button.grid(row=7, column=0, pady=(10,10))
 
         self.phosphohits = []
 
+        self.pb = ttk.Progressbar(self.frame, orient="horizontal", mode="determinate", length=300)
+        self.pb.grid(column=0, row=8, pady=(20, 0))
+
+    def step(self):
+        self.pb["value"] += 20
 
     def hydrophobicity_atomnumb(self):
         """dictionaries containing hydrophobicity values as determined by Kyte and Doolittle and number of atoms"""
@@ -141,6 +150,8 @@ class Entry_formular:
 
         """Clear all entries before run/ so that prior runs don't get overwritten"""
 
+        self.pb["value"] += 20
+        self.pb.update_idletasks()
         for entries in entryids:
             entries.delete(0,"end")
         entry_form.var.set(1)
@@ -170,14 +181,14 @@ class Entry_formular:
 
         for elements in entry_list:
             if elements in atomchangelib:
-                print(elements)
                 messagebox.showerror("Invalid Input","Please enter a valid input")
 
+        if entry_start == "":
+            messagebox.showerror("Invalid Input", "Please enter a valid input")
+
         if entry_start[-1] not in atomchangelib:  # if someone enters a non canonical aa we forbid that.
-            print(entry_start[-1])
             messagebox.showerror("Invalid Input", "Please enter a valid input")
         elif entry_start[0] not in atomchangelib:
-            print(entry_start[0])
             messagebox.showerror("Invalid Input", "Please enter a valid input")
 
 
@@ -468,6 +479,9 @@ class Entry_formular:
         """
         #secondary struc part comes here
 
+        self.pb["value"] += 20
+        self.pb.update_idletasks()
+
         cmd.load(pdbfile1)
         ids = []
         resis = []
@@ -581,6 +595,7 @@ class Entry_formular:
             global atom_ids
             global parsed_pdb_sasa
 
+
             atom_ids = []
             parsed_pdb_sasa = defaultdict(list)
 
@@ -680,6 +695,9 @@ class Entry_formular:
                 return normalized_sap_per_residue
 
         sap_score_residue_interest = sap_score(mutname)
+        self.pb["value"] += 20
+        self.pb.update_idletasks()
+
         #print(sap_score_residue_interest)
         entryids[6].insert(0, round(sap_score_residue_interest, 2))        #sap score calculated according to dominics method but shortcut, same accuracy as his method
         #8 digits after comma similar.
@@ -944,8 +962,8 @@ class Entryfield:
             self.label = tk.Label(self.frame, text=entries)
             self.entry = tk.Entry(self.frame, width=50)
             entryids.append(self.entry)
-            self.label.grid(column=0, row=idx, sticky="e")
-            self.entry.grid(column=1, row=idx, sticky="w")
+            self.label.grid(column=0, row=idx+1, sticky="e")
+            self.entry.grid(column=1, row=idx+1, sticky="w")
 
         for idx, entries in enumerate(attributeshown[6:]):
             self.label=tk.Label(self.frame, text=entries)
@@ -1036,15 +1054,15 @@ class Entryfield:
         self.frame5 = tk.Frame(self.frame)
         self.frame5.grid(row=14, column=0,columnspan=3, pady= 10)
 
-        self.clearbtn = tk.Button(self.frame5, text="Clear", command=self.clear_btn, borderwidth=4, width=10)
-        self.clearbtn.grid(row=1, column=5, sticky="we")
+        #self.clearbtn = tk.Button(self.frame5, text="Clear", command=self.clear_bn, borderwidth=4, width=10)
+        #self.clearbtn.grid(row=1, column=5, sticky="we")
 
         #self.subbutnlbl = tk.Label(self.frame5, text="")
         #self.subbutnlbl.grid(row=1, column=0, ipadx=10)
 
-        self.subbtn = tk.Button(self.frame5, text="Generate \n template file", relief="ridge",
-                                borderwidth=4, command=self.outfile_handler_weka, bg="blue", fg="white")
-        self.subbtn.grid(row=1, column=2, sticky="wnse")
+        #self.subbtn = tk.Button(self.frame5, text="Generate \n template file", relief="ridge",
+        #                        borderwidth=4, command=self.outfile_handler_weka, bg="blue", fg="white")
+        #self.subbtn.grid(row=1, column=2, sticky="wnse")
         #self.addmut = tk.Button(self.frame5, text="Add mutations",
         #                        command=self.add_mutants, borderwidth=4)
         #self.addmut.grid(row=1, column=5)
@@ -1052,68 +1070,68 @@ class Entryfield:
         #self.mut_info = tk.Button(self.frame5, text="Get mutations ids",
         #                        command=lambda: self.mut_ids(mutation_ids), borderwidth=4)
         #self.mut_info.grid(row=1, column=6, pady=10)
-        self.tutbutton = tk.Button(self.frame5, text="Read Tutorial", command=self.manual, borderwidth=4, width=20)
-        self.tutbutton.grid(row=1,column=6, sticky="we")
+        self.tutbutton = tk.Button(self.frame5, text="Read Tutorial", command=self.manual, borderwidth=4, width=15)
+        self.tutbutton.grid(row=1,column=0, sticky="we")
 
         self.phosphoinfoadd = tk.Button(self.frame5, text="Inspect Phospholibrary", command=self.phosphoinfoadder, borderwidth=4)
-        self.phosphoinfoadd.grid(row=1,column=3, sticky="we")
+        self.phosphoinfoadd.grid(row=1,column=1, sticky="we")
 
         self.bindinginfoadd = tk.Button(self.frame5, text="Inspect Bindinglibrary", command=self.bindinginfoadder, borderwidth=4)
-        self.bindinginfoadd.grid(row=1, column=4, sticky="we")
+        self.bindinginfoadd.grid(row=1, column=2, sticky="nwes")
 
         """Start WEKA related stuff"""
 
-        self.infoline = tk.Label(self.frame5, text="--------------------------------------------------  WEKA-Prediction  "
-                                                   "-----------------------------------------------------",font="Arial 12 bold")
-        self.infoline.grid(row=2, column=0, columnspan=7, pady=(20,0))
+        #self.infoline = tk.Label(self.frame5, text="--------------------------------------------------  WEKA-Prediction  "
+        #                                           "-----------------------------------------------------",font="Arial 12 bold")
+        #self.infoline.grid(row=2, column=0, columnspan=7, pady=(20,0))
 
         self.extndinfo = tk.Label(self.frame5, text="Eibe Frank, Mark A. Hall, and Ian H. Witten (2016).\n The WEKA Workbench. "
-                                                    "Online Appendix for 'Data Mining: Practical Machine Learning Tools and Techniques',\n Morgan Kaufmann, Fourth Edition, 2016."
-                                                    "\n\nFor this part you require a generated template file (blue button above)")
+                                                    "Online Appendix for 'Data Mining: Practical Machine Learning Tools and Techniques',\n Morgan Kaufmann, Fourth Edition, 2016.")
+        self.extndinfo.config(font="Helvetica 8")
         self.extndinfo.grid(row=3, column=0, columnspan=7)
 
 
         #buttons to make weka predictions
 
         self.frame6 = tk.Frame(self.frame)
-        self.frame6.grid(row = 16, column=0, pady=(50,10), columnspan=4)
+        self.frame6.grid(row = 0, column=0, pady=(20,50), columnspan=4)
 
-        self.frame6_1 = self.frame6 = tk.Frame(self.frame)
-        self.frame6_1.grid(row=15, column=0, pady=(10,60), columnspan=5)
+        #self.frame6_1 = tk.Frame(self.frame)
+        #self.frame6_1.grid(row=15, column=0, pady=(10,60), columnspan=5)
 
         #self.wekalbl = tk.Label(self.frame6, text="Here will be the weka stuff / placeholder")
         #self.wekalbl.grid(row=1, column=1, pady=20, sticky="w")
 
-        self.wekabtn = tk.Button(self.frame6_1, text="Prediction on\n pathogenicity", borderwidth=4, bg="red", fg="white",
-                                 relief="ridge", command=self.wekaprediction)
-        self.wekabtn.grid(row=3, column=0, columnspan=1, ipady=1, sticky="we")
-        self.wekabtntrainset = tk.Button(self.frame6_1, text="Trainingset info", borderwidth=4, command=self.trainingsetdetails)
-        self.wekabtntrainset.grid(row=3, column=1, sticky="we")
-        self.wekabtnmutantpdb = tk.Button(self.frame6_1, text="Clear", borderwidth=4, command=self.clearweka)
-        self.wekabtnmutantpdb.grid(row=3, column=2, sticky="we")
-        self.wekabtnoutputfile = tk.Button(self.frame6_1, text="Save mutation prediction", borderwidth=4, command=self.outputfilemutant)
-        self.wekabtnoutputfile.grid(row=3, column=3, sticky="we")
-        self.exitamiva = tk.Button(self.frame6_1, text="Exit AMIVA-F", command=self.exiting_amiva, borderwidth=4)
-        self.exitamiva.grid(row=3, column=4, sticky="we")
+        #self.wekabtn = tk.Button(self.frame5, text="Prediction on\n pathogenicity", borderwidth=4, bg="red", fg="white",
+        #                         relief="ridge", command=self.wekaprediction)
+        #self.wekabtn.grid(row=3, column=0, columnspan=1, ipady=1, sticky="we")
+        #self.wekabtntrainset = tk.Button(self.frame6_1, text="Trainingset info", borderwidth=4, command=self.trainingsetdetails)
+        #self.wekabtntrainset.grid(row=3, column=1, sticky="we")
+        self.wekabtnmutantpdb = tk.Button(self.frame5, text="Clear", borderwidth=4, command=self.fullclear)
+        self.wekabtnmutantpdb.grid(row=1, column=5, sticky="we")
+        self.wekabtnoutputfile = tk.Button(self.frame5, text="Save mutation prediction", borderwidth=4, command=self.outputfilemutant)
+        self.wekabtnoutputfile.grid(row=1, column=4, sticky="we")
+        self.exitamiva = tk.Button(self.frame5, text="Exit AMIVA-F", command=self.exiting_amiva, borderwidth=4)
+        self.exitamiva.grid(row=1, column=6, sticky="we")
 
 
         #self.wekaentrytag = tk.Label(self.frame6, text="WEKA-Output", font="Helvetica 13")
         #self.wekaentrytag.grid(row=5, column=0)
         self.wekaentryid = tk.Entry(self.frame6, width=10)
-        self.wekaentryid.grid(row=5, column=1, sticky="nsew")
+        self.wekaentryid.grid(row=1, column=1, sticky="nsew", ipady=6)
         self.wekaentrydomaininfo = tk.Entry(self.frame6, width=10)
-        self.wekaentrydomaininfo.grid(row=5, column=2, sticky="nseww")
+        self.wekaentrydomaininfo.grid(row=1, column=2, sticky="nsew")
         self.wekaentrydis = tk.Entry(self.frame6, width=15)
-        self.wekaentrydis.grid(row=5, column=3, sticky="nswe")
+        self.wekaentrydis.grid(row=1, column=3, sticky="nswe")
         #self.wekaentryconf = tk.Entry(self.frame6, width=5)
         #self.wekaentryconf.grid(row=5, column=4, sticky="nsew")
 
-        self.wekaentryidlbl = tk.Label(self.frame6, text="mutation", font="Helvetica 13")
-        self.wekaentryidlbl.grid(row=4, column=1, pady=(20,0))
-        self.wekaentrydomainlbl = tk.Label(self.frame6, text="domain", font="Helvetica 13")
-        self.wekaentrydomainlbl.grid(row=4, column=2, pady=(20, 0))
-        self.wekaentrydiseaselbl = tk.Label(self.frame6, text="pathogenicity", font="Helvetica 13")
-        self.wekaentrydiseaselbl.grid(row=4, column=3, pady=(20, 0))
+        self.wekaentryidlbl = tk.Label(self.frame6, text="mutation", font="Helvetica 16")
+        self.wekaentryidlbl.grid(row=0, column=1, pady=(0,0))
+        self.wekaentrydomainlbl = tk.Label(self.frame6, text="domain", font="Helvetica 16")
+        self.wekaentrydomainlbl.grid(row=0, column=2, pady=(0, 0))
+        self.wekaentrydiseaselbl = tk.Label(self.frame6, text="pathogenicity", font="Helvetica 16")
+        self.wekaentrydiseaselbl.grid(row=0, column=3, pady=(0, 0))
         #self.wekaentryconflbl = tk.Label(self.frame6, text="confidence", font="Helvetica 13")
         #self.wekaentryconflbl.grid(row=4, column=4, pady=(20, 0))
 
@@ -1168,13 +1186,24 @@ class Entryfield:
         self.wekaentryid.delete(0, tk.END)
         self.wekaentrydomaininfo.delete(0, tk.END)
         self.wekaentrydis.delete(0, tk.END)
+        #entry_form.clear_btn()
         #self.wekaentryconf.delete(0, tk.END)
 
 
+    def fullclear(self):
+        self.wekaentryid.delete(0, tk.END)
+        self.wekaentrydomaininfo.delete(0, tk.END)
+        self.wekaentrydis.delete(0, tk.END)
+        entry_form.clear_btn()
+        intro_form.button.config(bg="blue")
+        intro_form.pb["value"] = 0
 
     def wekaprediction(self):
         """Here we will do the wekabridging and the prediction for the mutations"""
         jvm.start()
+        intro_form.pb["value"] += 20
+        intro_form.pb.update_idletasks()
+
         self.clearweka()   #remove old stuff before new entries
         falsepredict = False    #if everything is fine this will stay false and we make a normal prediction
 
@@ -1215,6 +1244,9 @@ class Entryfield:
             resultconf =dist.tolist()
             prediction_disease_dict[inst.class_attribute.value(int(pred))] = resultconf[1]
 
+        intro_form.pb["value"] += 20
+        intro_form.pb.update_idletasks()
+
         #self.clear_btn()     #if something old is still there, remove it now
         #print("The prediction for your submitted mutation and its associated confidence are:")
 
@@ -1249,6 +1281,7 @@ class Entryfield:
                 self.wekaentryid.config(font="Helvetica 18")
                 self.wekaentrydomaininfo.insert(0, domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
+                intro_form.button.config(bg="red")
             else:
                 self.wekaentrydis.insert(0, "neutral/benign")
                 #self.wekaentryconf.insert(0, round(values,2))
@@ -1258,6 +1291,7 @@ class Entryfield:
                 self.wekaentryid.config(font="Helvetica 18")
                 self.wekaentrydomaininfo.insert(0,domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
+                intro_form.button.config(bg="green")
 
         if falsepredict == True:     #with wrong inputs we just clear random stuff that make no sense.
             self.clearweka()
@@ -1274,6 +1308,10 @@ class Entryfield:
             self.wekaentrydomaininfo.insert(0, domaininfo)
             self.wekaentrydomaininfo.config(font="Helvetica 18")
 
+        intro_form.pb["value"] = 0
+        intro_form.pb.update_idletasks()
+
+        #intro_form.pb.grid_forget()
         #self.wekatxt = tk.Label(self.frame6, text=intro_form.entry1.get())
         #self.wekatxt.grid(row=1, column=2, sticky="w")
 
@@ -1345,8 +1383,7 @@ class Entryfield:
         result = messagebox.askquestion("Exit", "Do you really want to quit AMIVA-?")
         if result == "yes":
             root.destroy()
-
-
+            jvm.stop()
 
 
 
@@ -1450,6 +1487,7 @@ class Entryfield:
                 outfile1.write(",")
                 outfile1.write("?")
 
+        self.wekaprediction()
 
 
     def add_mutants(self):
@@ -1483,5 +1521,7 @@ root = tk.Tk()
 trial = GUI(root)
 intro_form = Entry_formular(root)
 entry_form = Entryfield(root)
+
 root.mainloop()
 
+
